@@ -3,15 +3,15 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 
-import json, urllib.parse, gi
-gi.require_version('Soup', '3.0')
+import json, urllib.parse
+
 from gi.repository import Soup
 
 
 # Create a Soup session and set user agent
 
 session = Soup.Session.new()
-session.set_user_agent('Wike/3.1.1 (https://github.com/hugolabe)')
+session.set_user_agent('Wike/3.1.2 (https://github.com/hugolabe)')
 
 # Get Wikipedia random page
 
